﻿from random import randrange
from django.db import migrations, models
import django.db.models.deletion

# from electronics import models
import electronics


# Название модели типов компонентов
TABLE_TYPECOMPONENT = electronics.models.TypeComponent.__name__

# Определение имен разделов для типов электронных компонентов
SECTION_TRANSISTORS = "Транзисторы"
SECTION_DIODES = "Диоды"
SECTION_CAPACITORS = "Конденсаторы"
SECTION_RESISTORS = "Резисторы"


# def sectionTransistors():
#    return "Транзисторы"


# def sectionDiodes():
#    return "Диоды"


# def sectionCapacitors():
#    return "Конденсаторы"


# def sectionResistors():
#    return "Резисторы"


def populate_type_components(apps, schema_editor):
    # We get the model from the versioned app registry;
    # if we directly import it, it'll be the wrong version
    Type = apps.get_model("electronics", TABLE_TYPECOMPONENT)
    db_alias = schema_editor.connection.alias
    Type.objects.using(db_alias).bulk_create(
        [
            Type(
                # name="Транзисторы",
                name=SECTION_TRANSISTORS,
                description="Транзисторы — это полупроводниковые приборы, для усиления, \
                переключения и преобразования электрических сигналов.",
            ),
            Type(
                # name="Диоды",
                name=SECTION_DIODES,
                description="Диоды - это электронные приборы, пропускающие электрический \
                ток только в одном направлении – от плюса к минусу.",
            ),
            Type(
                # name="Конденсаторы",
                name=SECTION_CAPACITORS,
                description="Конденсаторы - электронные компоненты \
                для накопления заряда и энергии электрического поля.",
            ),
            Type(
                # name="Резисторы",
                name=SECTION_RESISTORS,
                description="Резисторы - пассивные элементы для ограничения силы тока.",
            ),
        ]
    )


def populate_components(apps, schema_editor):
    # We can't import the Person model directly as it may be a newer
    # version than this migration expects. We use the historical version.
    Type = apps.get_model("electronics", TABLE_TYPECOMPONENT)
    for type in Type.objects.all():
        if type.name == SECTION_TRANSISTORS:
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="BC857C",
                        description="Транзисторы общего назначения PNP в небольшом пластиковом корпусе SOT23.",
                        price=randrange(5, 1401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="S9012",
                        description="25 В 300 мВт 50 мА, 1 В 500 мА PNP SOT-23 Биполярные транзисторы - BJT ROHS",
                        price=randrange(5, 1401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="КТ235А9",
                        description="PNP транзисторы общего назначения. Полные аналоги транзисторов ВС856, ВС857 и ВС858.",
                        price=randrange(5, 1401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="2SA1015",
                        description="Кремниевый транзистор TOSHIBA PNP для усилителей звуковой частоты общего назначения.",
                        price=randrange(5, 1401),
                    ),
                ]
            )

        if type.name == SECTION_DIODES:
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="1N4148",
                        description="Диоды с быстрым переключением для малых токов.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="1N4007",
                        description="Диоды для выпрямления переменного тока в источниках питания общего назначения.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="M7",
                        description="Выпрямительный диод общего назначения для поверхностного монтажа.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="10A10",
                        description="Кремниевый выпрямительный диод на напряжения до 1000 вольт ток 10 ампер.",
                        price=randrange(5, 401),
                    ),
                ]
            )

        if type.name == SECTION_CAPACITORS:
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="CT8110bB2KV102K",
                        description="1000пф 2000в Y5P 10% дисковый конденсатор (К15-5). Высоковольтные аналог К15-5, К10-62.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="К10-17А М47",
                        description="Конденсаторы К10-17 для работы в цепях постоянного, переменного токов и в импульсных режимах.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="B41828A9474M007",
                        description="Конденсатор электролитический алюминиевый. 0.47 мкФ, 100 В, 105°C, размер 5x11мм.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="К50-35 мини",
                        description="Конденсаторы оксидно-электролитические алюминиевые для работы в цепях различных электрических токов.",
                        price=randrange(5, 401),
                    ),
                ]
            )

        if type.name == SECTION_RESISTORS:
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="CF-25 0.25 Вт, 1.8 Ом",
                        description="Резисторы с углеродным проводящим слоем предназначены для работы в цепях постоянного, переменного и импульсного тока.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="CF-50 0.5 Вт, 3.6 МОм",
                        description="Резистор углеродистый для работы в цепях постоянного, переменного и импульсного тока.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="0.062Вт 0402 1.6 Ом",
                        description="Чип резистор (SMD). Толстопленочные резисторы – для поверхностного монтажа.",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="CF-100 1 Вт, 5.1 МОм",
                        description="Резистор углеродистый CF-100 мощностью 1 Вт, номинал 5,6 кОм 5%.",
                        price=randrange(5, 401),
                    ),
                ]
            )


class Migration(migrations.Migration):
    dependencies = [("electronics", "0001_initial")]

    operations = [
        migrations.RunPython(populate_type_components),
        migrations.RunPython(populate_components),
    ]