﻿from random import randrange
from django.db import migrations, models
import django.db.models.deletion

# from electronics import models
import electronics

df = electronics.models.TypeComponent.__name__


# Определение имен разделов для типов электронных компонентов
def sectionTransistors():
    return "Транзисторы"


def sectionDiodes():
    return "Диоды"


def sectionCapacitors():
    return "Конденсаторы"


def sectionResistors():
    return "Резисторы"


def populate_type_components(apps, schema_editor):
    # We get the model from the versioned app registry;
    # if we directly import it, it'll be the wrong version
    Type = apps.get_model("electronics", "TypeComponent")
    db_alias = schema_editor.connection.alias
    Type.objects.using(db_alias).bulk_create(
        [
            Type(
                # name="Транзисторы",
                name=sectionTransistors(),
                description="Транзисторы — это полупроводниковые приборы, для усиления, \
                переключения и преобразования электрических сигналов.",
            ),
            Type(
                # name="Диоды",
                name=sectionDiodes(),
                description="Диоды - это электронные приборы, пропускающие электрический \
                ток только в одном направлении – от плюса к минусу.",
            ),
            Type(
                # name="Конденсаторы",
                name=sectionCapacitors(),
                description="Конденсаторы - электронные компоненты \
                для накопления заряда и энергии электрического поля.",
            ),
            Type(
                # name="Резисторы",
                name=sectionResistors(),
                description="Резисторы - пассивные элементы для ограничения силы тока.",
            ),
        ]
    )


def populate_components(apps, schema_editor):
    # We can't import the Person model directly as it may be a newer
    # version than this migration expects. We use the historical version.
    Type = apps.get_model("electronics", "TypeComponent")
    for type in Type.objects.all():
        if type.name == sectionTransistors():
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="BC857C",
                        description="",
                        price=randrange(5, 1401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="S9012",
                        description="",
                        price=randrange(5, 1401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="КТ235А9",
                        description="",
                        price=randrange(5, 1401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="2SA1015",
                        description="",
                        price=randrange(5, 1401),
                    ),
                ]
            )

        if type.name == sectionDiodes:
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="1N4148",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="1N4007",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="M7",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="10A10",
                        description="",
                        price=randrange(5, 401),
                    ),
                ]
            )

        if type.name == sectionCapacitors:
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="CT8110bB2KV102K",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="К10-17А М47",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="B41828A9474M007",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="К50-35 мини",
                        description="",
                        price=randrange(5, 401),
                    ),
                ]
            )

        if type.name == sectionResistors:
            Component = apps.get_model("electronics", "Component")
            db_alias = schema_editor.connection.alias
            Component.objects.using(db_alias).bulk_create(
                [
                    Component(
                        type_foreignkey=type,
                        name="CF-25 0.25 Вт, 1.8 Ом",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="CF-50 0.5 Вт, 3.6 МОм",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="0.062Вт 0402 1.6 Ом",
                        description="",
                        price=randrange(5, 401),
                    ),
                    Component(
                        type_foreignkey=type,
                        name="CF-100 1 Вт, 5.1 МОм",
                        description="",
                        price=randrange(5, 401),
                    ),
                ]
            )


class Migration(migrations.Migration):
    dependencies = [("electronics", "populate_data")]

    operations = [
        migrations.RunPython(populate_type_components),
        migrations.RunPython(populate_components),
    ]